# mypy-boto3-efs

[![PyPI - mypy-boto3-efs](https://img.shields.io/pypi/v/mypy-boto3-efs.svg?color=blue)](https://pypi.org/project/mypy-boto3-efs)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-efs.svg?color=blue)](https://pypi.org/project/mypy-boto3-efs)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dw/mypy-boto3-efs?color=blue)](https://pypistats.org/packages/mypy-boto3-efs)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/master/logo.png)

Type annotations for
[boto3.EFS 1.17.67](https://boto3.amazonaws.com/v1/documentation/api/1.17.67/reference/services/efs.html#EFS)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-buider 4.10.0](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[mypy-boto3-efs docs](https://github.com/vemel/mypy_boto3_builder/service_docs/mypy_boto3_efs/README.md)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/master/demo.gif)

- [mypy-boto3-efs](#mypy-boto3-efs)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)

## How to install

Install `boto3-stubs` for `EFS` service.

```bash
python -m pip install boto3-stubs[efs]
```

## Usage

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[efs]` in your environment:
  `python -m pip install 'boto3-stubs[efs]'`

Both type checking and auto-complete should work for `EFS` service. No explicit
type annotations required, write your `boto3` code as usual.

### PyCharm

- Install `boto-stubs[efs]` in your environment:
  `python -m pip install 'boto3-stubs[efs]'`

Both type checking and auto-complete should work for `EFS` service. No explicit
type annotations required, write your `boto3` code as usual. Auto-complete can
be slow on big projects or if you have a lot of installed `boto3-stubs`
submodules.

### Other IDEs

Not tested, but as long as your IDE support `mypy` or `pyright`, everything
should work.

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[efs]` in your environment:
  `python -m pip install 'boto3-stubs[efs]'`
- Run `mypy` as usual

Type checking should work for `EFS` service. No explicit type annotations
required, write your `boto3` code as usual.

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[efs]` in your environment:
  `python -m pip install 'boto3-stubs[efs]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `EFS` service. No explicit type annotations
required, write your `boto3` code as usual.

## Explicit type annotations

### Client annotations

`EFSClient` provides annotations for `boto3.client("efs")`.

```python
import boto3

from mypy_boto3_efs import EFSClient

client: EFSClient = boto3.client("efs")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: EFSClient = session.client("efs")
```

### Paginators annotations

`mypy_boto3_efs.paginator` module contains type annotations for all paginators.

```python
from mypy_boto3_efs import EFSClient
from mypy_boto3_efs.paginator import (
    DescribeFileSystemsPaginator,
    DescribeMountTargetsPaginator,
    DescribeTagsPaginator,
)

client: EFSClient = boto3.client("efs")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
describe_file_systems_paginator: DescribeFileSystemsPaginator = client.get_paginator("describe_file_systems")
describe_mount_targets_paginator: DescribeMountTargetsPaginator = client.get_paginator("describe_mount_targets")
describe_tags_paginator: DescribeTagsPaginator = client.get_paginator("describe_tags")
```

### Literals

`mypy_boto3_efs.literals` module contains literals extracted from shapes that
can be used in user code for type checking.

```python
from mypy_boto3_efs.literals import (
    DescribeFileSystemsPaginatorName,
    DescribeMountTargetsPaginatorName,
    DescribeTagsPaginatorName,
    LifeCycleState,
    PerformanceMode,
    Status,
    ThroughputMode,
    TransitionToIARules,
)

def check_value(value: DescribeFileSystemsPaginatorName) -> bool:
    ...
```

### Typed dictionaries

`mypy_boto3_efs.type_defs` module contains structures and shapes assembled to
typed dictionaries for additional type checking.

```python
from mypy_boto3_efs.type_defs import (
    AccessPointDescriptionTypeDef,
    BackupPolicyDescriptionTypeDef,
    BackupPolicyTypeDef,
    CreationInfoTypeDef,
    DescribeAccessPointsResponseTypeDef,
    DescribeFileSystemsResponseTypeDef,
    DescribeMountTargetSecurityGroupsResponseTypeDef,
    DescribeMountTargetsResponseTypeDef,
    DescribeTagsResponseTypeDef,
    FileSystemDescriptionTypeDef,
    FileSystemPolicyDescriptionTypeDef,
    FileSystemSizeTypeDef,
    LifecycleConfigurationDescriptionTypeDef,
    LifecyclePolicyTypeDef,
    ListTagsForResourceResponseTypeDef,
    MountTargetDescriptionTypeDef,
    PaginatorConfigTypeDef,
    PosixUserTypeDef,
    RootDirectoryTypeDef,
    TagTypeDef,
)

def get_structure() -> AccessPointDescriptionTypeDef:
    return {
      ...
    }
```
